<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lv">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Noklikšķiniet uz ikonas
vai vēlreiz nospiediet saīsni, lai pārtrauktu ierakstīšanu</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nerotējiet ekrānu ieraksta laikā</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Zīmēšana</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekrāna ierakstīšana</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Saglabāšana neizdevās. Lūzu saglabājiet mājas mapē</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekrāna uzņēmums izveidots</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>izvēlēties-laukumu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorēt</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saglabā ekrāna ierakstu, lūdzu uzgaidiet...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Tā kā procesa laikā loga efekts ir atspējots, ieraksts ir jāpārtrauc</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Ekranšotu nevarēja izņemt.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Iezīmēt ekranšotus</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Atvērt mapi</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Ekranšotu izdarīja un kopēja uz līstī</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Iezīmēt ekranšotus</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekranšot</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Zīmēt</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekranšot</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Zīmēšana</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Ieraksts pabeigts</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Atvērt mapi</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekrāna ierakstīšana sāksies pēc %1 sekundēm</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Iegūt palīdzību.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Neizdevās izņemt nepārtrauktu ekranšotu.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Sasniedzāt apakšējo robežu skrūvējamā zonā</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Sasniedzāt maksimālo garumu</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Pareizināt iezīmēšanas zonu</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Skrūvējiet peli vai noklikšķiniet, lai izņemtu scroll ekranšotu</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Lēcināt scroll ātrumu</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Nepareiza zona, noklikšķiniet, lai </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Ievadiet tekstu šeit</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Sākt/Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Iziet/Saglabāt</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Pielāgot izmēru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Ātrais sākums</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Loga ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atlikt ekrānuzņēmumu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Viss ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Taisnstūris</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Līnija</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Zīmulis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksts</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Palielināt augstumu augšā</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Palielināt augstumu lejā</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Palielināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Palielināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Samazināt augstumu augšā</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Samazināt augstumu lejā</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Samazināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Samazināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rādīt saīsnes</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Skaņa</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Taustiņa nospiešana</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Sākt ierakstu</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Sākt/Ierakstīt</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pele</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Instrumenti</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Izņemt tekstu</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Iezīmēt ekranšotus</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Sākt OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Sākt scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bulta</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Zīmēt</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Taisnstūris
Ietvert Shift, lai izveidotu kvadrātu</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipse
Ietvert Shift, lai izveidotu riņķi</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pīlā
Spiedīt Shift, lai izveidotu taisnu līniju</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Regulējiet nešarpu stiprību (pārvietojiet, lai regulējat</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Regulējiet pīlā izmēru (pārvietojiet, lai regulējat</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Regulējiet teksta izmēru (pārvietojiet, lai regulējat</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Pašķiept vai vilkt, lai
izvēlētos zonu, ko reģistrēs</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Rādīt tastatūras ierakstu (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Paslēpt tastatūras ierakstu (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Rādīt tastatūras ierakstu (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Ieslēgt kameru (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Izslēgt kameru (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Iestatījumi (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formāts:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Kadri sekundē:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 kadri sekundē</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 kadri sekundē</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 kadri sekundē</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 kadri sekundē</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 kadri sekundē</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Skaņa</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofons</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Sistēmas audio</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Rādīt rādītāju</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Rādīt klikšķi</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Darbavirsma</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Taisnstūris (R)
Saspiediet Shift, lai izveidotu kvadrātu</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Elipse (O)
Saspiediet Shift, lai izveidotu riņķi</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Līnija (L)
Saspiediet Shift, lai izveidotu vertikālu vai horizontālu līniju</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Stipra (X)
Saspiediet Shift, lai izveidotu vertikālu vai horizontālu stipru</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Pīlā (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Nešarps (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Teksts (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Pārvietojiet (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Izvelēties tekstu (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Izvēlēties ziņojumus (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Atcelt (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Attēli</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mape</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Iestatīt ceļu saglabāšanai</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Mainīt ceļu saglabāšanai</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formāts</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Rindas efekti</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Neviens</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Tumšums</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Robe</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Ierīce</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Izvilkum teksta</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Aizvērt (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>Lielisks (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Atzimējiet ieraksta laukumu iekļaujoties %1*%2 lai iegūtu labāku video</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Ekrāna reģistrācija šajā laikā nav atbalstīta</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Jauna reģistrācija</translation>
    </message>
</context>
</TS>
